/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 27 Nov 2023
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_BL.dta", clear

// Rename some variables
	ren (stimul_index wealth_index) (stimul_index_gsem wealth_index_gsem)
	ren (stimul_index_zi wealth_index_zi) (stimul_index wealth_index)

*-------------------------------------------------------------------------------*
*									TABLE 1										*
*-------------------------------------------------------------------------------*

// Table 1: Baseline Summary Statistics

	* Target children aged 3 to 5 **************************************************
	glo c_ind "total_score_zi_nostd score_com_zi_nostd score_grossmotor_zi_nostd score_finemotor_zi_nostd score_pbmsolving_zi_nostd score_socioperso_zi_nostd"

	glo target 		"female ageinmonth wenttopreschl zhfa_35 ${c_ind}"
	glo if_target 	"if target_35==1 & TARGET_GROUP!=1"

	* Empty matrices
	mat rs = J(1,6,.)
	mat coln rs = ctrl sd_ctrl treat sd_treat pval n
	loc vars "${target}"
	foreach v in `vars'{
		qui areg `v' treatment_ecd ${if_target}, a(DIST_ID) vce(cluster COM_ID)
		local N = e(N)
		qui test treatment_ecd
		local pval = r(p)
		qui tabstat `v' ${if_target}, by(treatment_ecd) stat(mean sd) save nototal
		mat r = [r(Stat1)[1,1], r(Stat1)[2,1], r(Stat2)[1,1], r(Stat2)[2,1], `pval', `N']
		mat rown r = `v'
		mat rs = [rs \ r]
	}
	matlist rs
	mat res = rs

	// Test for joint orthogonality
	*sum ${target}
	areg treatment_ecd ${target} ${if_target}, a(DIST_ID) vce(cluster COM_ID)
	qui test
	mat f_target = [r(F), r(p), e(N)]
	mat coln f_target = F pval N

	* Caregiver ********************************************************************
	glo caregiver 		"female IDADE speaks_port noschooling educ_year illiterate"
	glo if_caregiver 	"if CH01_35==MemberId & TARGET_GROUP!=1"

	* Empty matrices
	mat rs = J(1,6,.)
	mat coln rs = ctrl sd_ctrl treat sd_treat pval n
	loc vars "${caregiver}"
	foreach v in `vars'{
		qui areg `v' treatment_ecd ${if_caregiver}, a(DIST_ID) vce(cluster COM_ID)
		local N = e(N)
		qui test treatment_ecd
		local pval = r(p)
		qui tabstat `v' ${if_caregiver}, by(treatment_ecd) stat(mean sd) save nototal
		mat r = [r(Stat1)[1,1], r(Stat1)[2,1], r(Stat2)[1,1], r(Stat2)[2,1], `pval', `N']
		mat rown r = `v'
		mat rs = [rs \ r]
	}
	matlist rs
	mat res = [ res \ rs ]
	matlist res

	// Test for joint orthogonality
	*sum ${caregiver}
	areg treatment_ecd ${caregiver} ${if_caregiver}, a(DIST_ID) vce(cluster COM_ID)
	qui test
	mat f_caregiver = [r(F), r(p), e(N)]
	mat coln f_caregiver = F pval N

	* Household ********************************************************************
	glo hh 		"stimul_index AF05 nbr_children nbr_children35 C01 wealth_index"
	glo if_hh	"if relationToHead==1 & TARGET_GROUP!=1"

	* Empty matrices
	mat rs = J(1,6,.)
	mat coln rs = ctrl sd_ctrl treat sd_treat pval n
	loc vars "${hh}"
	foreach v in `vars'{
		qui areg `v' treatment_ecd ${if_hh}, a(DIST_ID) vce(cluster COM_ID)
		local N = e(N)
		qui test treatment_ecd
		local pval = r(p)
		qui tabstat `v' ${if_hh}, by(treatment_ecd) stat(mean sd) save nototal
		mat r = [r(Stat1)[1,1], r(Stat1)[2,1], r(Stat2)[1,1], r(Stat2)[2,1], `pval', `N']
		mat rown r = `v'
		mat rs = [rs \ r]
	}
	matlist rs
	mat res = [ res \ rs ]
	matlist res

	// Test for joint orthogonality
	*sum ${hh}
	areg treatment_ecd ${hh} ${if_hh}, a(DIST_ID) vce(cluster COM_ID)
	qui test
	mat f_hh = [r(F), r(p), e(N)]
	mat coln f_hh = F pval N

	// Overall 
	dis "${target}"
	glo tgt "wenttopreschl_hh zhfa_35 ${c_ind}"
	tabmiss ${tgt} ${caregiver} ${hh} if relationToHead==1
	areg treatment_ecd ${tgt} ${caregiver} ${hh} if relationToHead==1, a(DIST_ID) vce(cluster COM_ID)
	qui test
	mat f_all = [r(F), r(p), e(N)]
	mat coln f_all = F pval N

	mat Join_F = [f_target \ f_caregiver \ f_hh \ f_all]
	mat rown Join_F = Target Caregiver HH All_vars
	matlist Join_F
	mat fstat = Join_F[4..4,1...]
}	
// OUTPUT TABLE
	glo title "Table 1: Baseline Summary Statistics"
	glo notes "Notes: SD stands for Standard Deviation and N for the number of observations. ASQ refers to measures of skills from the standard Ages-and-Stages Questionnaire described in section 4."

	frmttable, statmat(res) sdec(3,3,3,3,3,0) ///
		ctitles("","(1)","(2)","(3)","(4)","(5)","(6)" \ ///
				"", "Control", "", "Treatment", "", "p-value", " " \ ///
				"Variable","Mean","SD","Mean","SD","(1)-(3)","N") ///
		rtitles("Panel A. Target child's characteristics" \ ///
				"    Female (\%)" \ ///
				"    Age of target (years)" \ ///
				"    Attended preschool (\%)" \ ///
				"    Height-for-age z-score" \ ///
				"    Total ASQ score" \ ///
				"       ASQ Communication" \ ///
				"       ASQ Gross Motor Coordination" \ ///
				"       ASQ Fine Motor Coordination" \ ///
				"       ASQ Problem Solving" \ ///
				"       ASQ Socio-personal"  \ ///
				"Panel B. Caregiver's characteristics" \ ///
				"    Female (\%)" \ ///
				"    Age (years)" \ ///
				"    Speaks Portuguese (\%)" \ ///
				"    No schooling (\%)" \ ///
				"    Years of schooling" \ ///
				"    Is illiterate (\%)" \ ///
				"Panel C. Household characteristics" \ ///
				"    Stimulation Index (Activities with children)" \ ///
				"    Household Size" \ ///
				"    Number of children aged 0-18" \ ///
				"    Number of children aged 3-5 in HH" \ ///
				"    Household receives remittances" \ ///
				"    Wealth index") ///
		nocenter tex fragment replace hlines(0{0};1{0}1) ///
		title("${title}") ///
		note("${notes}")

	// Joint F-test
	glo title "Joint F-test"
	frmttable, statmat(fstat) sdec(3,3,0) ///
		ctitles("","(1)","(2)","(3)" \ ///
				"","F Stat.","P-Value","N") ///
		rtitles("Joint F-test") ///
		nocenter tex fragment replace hlines(0{0};1{0}1) ///
		pretext("${title}")

	/*
	frmttable, statmat(Join_F) sdec(3,3,0) ///
		ctitles("","(1)","(2)","(3)" \ ///
				"","F Stat.","P-Value","N") ///
		rtitles("Target child's characteristics" \ ///
				"Caregiver's characteristics" \ ///
				"Household characteristics" \ ///
				"Overall") ///
		nocenter tex fragment replace hlines(0{0};1{0}1) ///
		pretext("${title}")
	**/