/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Jan 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/
qui{
// Load data
	use "${data}\data_EL.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Labels and variables
	la var older_sibling "Older Sibling"
	la var treatment_ecd "Treatment"
	la var female "Female"

	*** Older sisters
	tab older_sibling female, m

	gen older_sister = (older_sibling==1 & female==1 & calc_age > 13)
	tab older_sister istarget
	bys HH_ID: egen n_old_sister = total(older_sister)
	tab n_old_sister, m

	** Older brothers
	gen older_bro = (older_sibling==1 & female==0 & calc_age > 13)
	tab older_bro istarget
	bys HH_ID: egen n_old_brothers = total(older_bro)
	tab n_old_brothers, m

	la var n_old_sister "Number of older sisters aged 14 - 18 present at endline"
	la var n_old_brothers "Number of older brothers aged 14 - 18 present at endline"
	la var older_sibling "Older Sibling"
	la var treatment_ecd "Treatment"
	la var female "Female"
	
*-------------------------------------------------------------------------------*
*									TABLE A7									*
*-------------------------------------------------------------------------------*
// Table 9: Preschool & Primary School Enrollment Spillovers on Siblings
	glo if "if istarget35!=1 & sibling==1"
	
	tab calc_age if wenttopreschl==1 & istarget35!=1 & sibling==1 & calc_age<=6
	
	** Westfall & Young P-Values
	local vars "wenttopreschl"
	wyoung `vars', cmd(areg OUTCOMEVAR treatment_ecd ${if} & calc_age<=6 [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)) ///
		familyp(treatment_ecd) bootstraps(${reps}) seed(123) strata(DIST_ID) cluster(COM_ID) /*singlestep detail*/
	mat m1 = r(table)[1...,4]
	mat rown m1 = `vars'

	local vars "enroledatschool"
	wyoung `vars', cmd(areg OUTCOMEVAR treatment_ecd ${if} & calc_age>=6 & calc_age<=12 & female==1 [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)) ///
		familyp(treatment_ecd) bootstraps(${reps}) seed(123) strata(DIST_ID) cluster(COM_ID) /*singlestep detail*/
	mat m2 = r(table)[1...,4]
	mat rown m2 = `vars'

	local vars "enroledatschool"
	wyoung `vars', cmd(areg OUTCOMEVAR treatment_ecd ${if} & calc_age>=6 & calc_age<=12 & female==0 [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)) ///
		familyp(treatment_ecd) bootstraps(${reps}) seed(123) strata(DIST_ID) cluster(COM_ID) /*singlestep detail*/
	mat m3 = r(table)[1...,4]
	mat rown m3 = `vars'

	mat mat = [ [m1[1,1] \ J(1,1,.) \ J(1,1,.)] , [J(1,1,.) \ m2[1,1] \ m3[1,1]] ]
	matlist mat

	/*
	went to preschool for siblings 6 and below

	3 estimations:
	currently enrolled in primary for siblings 6-12
	currently enrolled in primary for sisters 6-12
	currently enrolled in primary for brothers 6-12
	*/
	local vars "wenttopreschl enroledatschool"
	tabmiss `vars' ${if}
	eststo clear
	local k = 1
	foreach var in `vars'{
		dis in red "`k'" 
		local pval = mat[`k',1]
		*dis in red `"`var':"', in yellow `"`:var label `var''"'
		if "`var'"=="wenttopreschl"{
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age<=6, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 		   	  `var' ${if} & treatment==0 & calc_age<=6
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix wy = `pval'
			local k = `k'+1
		}
		if "`var'"=="enroledatschool"{
			* currently enrolled in primary for sisters 6-12
			local pval = mat[`k',2]
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==1, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 			  `var' ${if} & older_sibling==1 & treatment==0 & calc_age>=6 & calc_age<=12 & female==1
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix wy = `pval'
			local k = `k'+1
			
			* currently enrolled in primary for brothers 6-12
			local pval = mat[`k',2]
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==0, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 			  `var' ${if} & older_sibling==1 & treatment==0 & calc_age>=6 & calc_age<=12 & female==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix wy = `pval'
			local k = `k'+1
		}
	}
	eststo dir

// Columns 4 and 5
** Westfall & Young P-Values
	local vars "n_old_sister n_old_brothers"
	wyoung `vars', cmd(areg OUTCOMEVAR treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)) ///
		familyp(treatment_ecd) bootstraps(${reps}) seed(123) strata(DIST_ID) cluster(COM_ID) /*singlestep detail*/
	mat mat 	 = r(table)[1...,4]
	mat rown mat = `vars'
	matlist mat

	glo if "if tag==1" // for households
	local k = 4
	local vars "n_old_sister n_old_brothers"
	foreach var in `vars'{
		local pval = mat[`k'-3,1]
		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix wy = `pval'
		local k = `k'+1
	}
}
// OUTPUT TABLE
	glo title "Table A7: Preschool & Primary School Enrollment Spillovers on Siblings"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the sibling-level are presented using outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Westfall and Young (1993) p-values are shown in square brackets, where 10,000 replications were used. Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) wy(par([ ]) fmt(3)) ) label varlabels(c1 " ") nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes order(treatment_ecd) compress drop(_cons)
