/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/

// Load data
	use "${data}\data_EL.dta", clear
		
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

// Missings of controls imputation
	sum wealth_index_${ind}_BL, d
	glo mdn = r(p50)
	gen above_median_wealth = (wealth_index_${ind}_BL > ${mdn})
	la var above_median_wealth "Above median wealth"

	*ren relationtohead relationtohead_EL // Relation to head (if new member at EL)

	la var calc_age "Age (years)"
	glo c_ind "score_com_zi score_grossmotor_zi score_finemotor_zi score_pbmsolving_zi score_socioperso_zi"

	* Target children aged 3 to 5 **************************************************
	glo target 		"			  zhfa_35_BL ${c_ind}"

	* Caregiver ********************************************************************
	glo caregiver 		"			  speaks_port_resp_BL noschooling_resp_BL educ_resp_BL illiterate_resp_BL"

	* Household ********************************************************************
	glo hh 		"stimul_index_BL AF05 nbr_children_BL nbr_children35_BL C01_BL wealth_index_BL"

	glo controls female calc_age ${target} ${caregiver} ${hh}
	dis "${controls}"

	desc ${controls}
	tabmiss ${controls}

	* Missing imputation of controls with global mean (according to group)
	**According to group
	* Overall
	foreach x in calc_age{
		qui sum `x'
		gen 	`x'_ori = `x'
		replace `x' 	= r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* Child level
	foreach x in zhfa_35_BL $c_ind{
		qui sum `x' if istarget35==1
		gen 	`x'_ori = `x'
		replace `x' 	= r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* Caregiver
	foreach x in speaks_port_resp_BL noschooling_resp_BL educ_resp_BL illiterate_resp_BL{
		qui sum `x' if CH01_35==MemberId, d
		gen 	`x'_ori = `x'
		if inlist("`x'", "speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL"){
			replace `x' = r(p50) if `x'==. // median for dummies
		}
		if inlist("`x'", "educ_resp_BL"){
			replace `x' = round(r(mean)) if `x'==. // mean for continuos
		}
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* HH level
	egen HH_tag = tag(HH_ID)
	foreach x in C01_BL wealth_index_BL{
		qui sum `x' if HH_tag==1
		gen 	`x'_ori = `x'
		replace `x' = round(r(mean)) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	tabmiss ${controls}

	* Define depvars for which you want to apply lasso
	global composition  "treatment_ecd"
	destring DIST_ID, replace

*-------------------------------------------------------------------------------*
*									TABLE A8									*
*-------------------------------------------------------------------------------*
	macro drop ctrls*

// Table A8: First Stage & ITT Impacts on Primary School Enrollment (LASSO Controls)
	glo if "if istarget35==1"
	local vars "wenttopreschl enroledatschool schl_repetition_uncon app_grade1 enrolment_zi"

	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	eststo clear
	local k = 1
	foreach y of local vars{
		macro drop add
		qui dsregress `y' treatment_ecd i.DIST_ID ${if}, controls(${controls}) rseed(123) vce(cluster COM_ID)
		
		dis "`y' = `e(controls_sel)'"
		local cols: word count ${controls}
		mat ctrl = J(1,`cols',.)
			
		local j = 1
		foreach c in ${controls}{
			mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
			local j = `j'+1
		}
		mat rown ctrl = `y'
		mat sl = [ sl \ ctrl]
		
		glo ctrls`k' "`e(controls_sel)'"
		** Postlasso
		qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum `y' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
		
		glo `y': variable label `y'
	}
	*eststo dir
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

	// TABLE
	glo title "Table A7: First Stage & ITT Impacts on Primary School Enrollment (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. The Primary School Enrollment Index is constructed over columns (2) to (4). All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") star(* 0.10 ** 0.05 *** 0.01) interaction(" X ") title("${title}") replace addnotes("${notes}") nonotes noomit keep(treatment_ecd)

*-------------------------------------------------------------------------------*
*									TABLE A9									*
*-------------------------------------------------------------------------------*
// Table A9: ITT Impacts on Child Cognitive and Social-Emotional Skills (LASSO Controls)
	macro drop ctrls*
	tab istarget35 missingMELQO

	glo if "if istarget35==1"
	local vars "Preliteracy_${ind} Premath_${ind} Executive_funct_${ind} Socioemo_cogn_${ind} Fine_motor_${ind} literacyinterest_${ind} skills_${ind}"

	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	eststo clear
	local k = 1
	foreach y of local vars{
		macro drop add
		qui dsregress `y' treatment_ecd i.DIST_ID ${if}, controls(${controls}) rseed(123) vce(cluster COM_ID)
		
		dis "`y' = `e(controls_sel)'"
		local cols: word count ${controls}
		mat ctrl = J(1,`cols',.)
			
		local j = 1
		foreach c in ${controls}{
			mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
			local j = `j'+1
		}
		mat rown ctrl = `y'
		mat sl = [ sl \ ctrl]
		
		glo ctrls`k' "`e(controls_sel)'"
		** Postlasso
		qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum `y' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
		
		glo `y': variable label `y'
	}
	*eststo dir
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

// OUTPUT TABLE
	glo title "Table A8: ITT Impacts on Child Cognitive and Social-Emotional Skills (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Effects expressed in units of standard deviations of control group. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab, b(3) se(3) label  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" X ") title("${title}") replace addnotes("${notes}") nonotes noomit keep(treatment_ecd)

*-------------------------------------------------------------------------------*
*									TABLE A10									*
*-------------------------------------------------------------------------------*
// Table A10: Preschool & Primary School Enrollment Spillovers on Siblings (LASSO Controls)
	macro drop ctrls*

	la var older_sibling "Older Sibling"
	la var treatment_ecd "Treatment"
	la var female "Female"

	*** Older sisters
	tab older_sibling female, m

	gen older_sister = (older_sibling==1 & female==1 & calc_age > 13)
	tab older_sister istarget
	bys HH_ID: egen n_old_sister = total(older_sister)
	tab n_old_sister, m

	** Older brothers
	gen older_bro = (older_sibling==1 & female==0 & calc_age > 13)
	tab older_bro istarget
	bys HH_ID: egen n_old_brothers = total(older_bro)
	tab n_old_brothers, m

	la var n_old_sister "Number of older sisters aged 14 - 18 present at endline"
	la var n_old_brothers "Number of older brothers aged 14 - 18 present at endline"

	glo if "if istarget35!=1 & sibling==1"

	local vars "wenttopreschl enroledatschool"
	tabmiss `vars' ${if}

	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	eststo clear
	local k = 1
	foreach y of local vars{
		macro drop add
		if "`y'"=="wenttopreschl"{
			qui dsregress `y' treatment_ecd i.DIST_ID ${if} & calc_age<=6, controls(${controls}) rseed(123) vce(cluster COM_ID)
			
			dis "`y' = `e(controls_sel)'"
			local cols: word count ${controls}
			mat ctrl = J(1,`cols',.)
				
			local j = 1
			foreach c in ${controls}{
				mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
				local j = `j'+1
			}
			mat rown ctrl = `y'
			mat sl = [ sl \ ctrl]
			
			glo ctrls`k' "`e(controls_sel)'"
			** Postlasso
			qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum `y' ${if} & calc_age<=6 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			local k = `k'+1
		}
		
		if "`y'"=="enroledatschool"{
			qui dsregress `y' treatment_ecd i.DIST_ID ${if} & calc_age>=6 & calc_age<=12, controls(${controls}) rseed(123) vce(cluster COM_ID)
			
			dis "`y' = `e(controls_sel)'"
			local cols: word count ${controls}
			mat ctrl = J(1,`cols',.)
				
			local j = 1
			foreach c in ${controls}{
				mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
				local j = `j'+1
			}
			mat rown ctrl = `y'
			mat sl = [ sl \ ctrl]
			
			glo ctrls`k' "`e(controls_sel)'"
			** Postlasso
			qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==1, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum `y' ${if} & calc_age>=6 & calc_age<=12 & female==1 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			local k = `k'+1
			
			qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==0, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum `y' ${if} & calc_age>=6 & calc_age<=12 & female==0 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			local k = `k'+1
		}
		
		glo `y': variable label `y'
	}
	eststo dir

	glo if "if tag==1" // for households
	local vars "n_old_sister n_old_brothers"
	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	local k = 4
	foreach y of local vars{
		macro drop add
		qui dsregress `y' treatment_ecd i.DIST_ID ${if}, controls(${controls}) rseed(123) vce(cluster COM_ID)
		
		dis "`y' = `e(controls_sel)'"
		local cols: word count ${controls}
		mat ctrl = J(1,`cols',.)
			
		local j = 1
		foreach c in ${controls}{
			mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
			local j = `j'+1
		}
		mat rown ctrl = `y'
		mat sl = [ sl \ ctrl]
		
		glo ctrls`k' "`e(controls_sel)'"
		** Postlasso
		qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum `y' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
		
		glo `y': variable label `y'
	}
	eststo dir

	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

	// CORRECTION (needed for this case)
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if !strpos("$ctrls", "`x'") glo ctrls "${ctrls} `x'"
		}
	}

// OUTPUT TABLE
	glo title "Table A9: Preschool & Primary School Enrollment Spillovers on Siblings (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Control mean") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes noomit rename(1.treatment_ecd treatment_ecd) keep(treatment_ecd) compress
 

*-------------------------------------------------------------------------------*
*									TABLE A11									*
*-------------------------------------------------------------------------------*

	macro drop ctrls*
// Table A11: Household Labor Supply by Gender (LASSO Controls)
	use "${data}\data_labor_wealth_EL.dta", clear
	do "${dofiles}\DICIPE_VarLabels.do"

	glo controls female calc_age ${target} ${caregiver} ${hh}
	dis "${controls}"

	desc ${controls}
	tabmiss ${controls}

	* Missing imputation of controls with global mean (according to group)
	**According to group
	* Overall
	foreach x in calc_age{
		qui sum `x'
		gen 	`x'_ori = `x'
		replace `x' 	= r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* Child level
	foreach x in zhfa_35_BL $c_ind{
		qui sum `x' if istarget35==1
		gen 	`x'_ori = `x'
		replace `x' 	= r(mean) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* Caregiver
	foreach x in speaks_port_resp_BL noschooling_resp_BL educ_resp_BL illiterate_resp_BL{
		qui sum `x' if CH01_35==MemberId, d
		gen 	`x'_ori = `x'
		if inlist("`x'", "speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL"){
			replace `x' = r(p50) if `x'==. // median for dummies
		}
		if inlist("`x'", "educ_resp_BL"){
			replace `x' = round(r(mean)) if `x'==. // mean for continuos
		}
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	* HH level
	egen HH_tag = tag(HH_ID)
	foreach x in C01_BL wealth_index_BL{
		qui sum `x' if HH_tag==1
		gen 	`x'_ori = `x'
		replace `x' = round(r(mean)) if `x'==.
		local l: variable label `x'
		la var `x'_ori "`l'"
	}
	tabmiss ${controls}

	numlabel, add
	tab wk_age_range, m

	local vars "isworking isworking isworking isworking isworking isworking"
	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	local depvars "isworking"
	eststo clear
	loc a = 1
	forval n = 1/3{
		foreach y of local depvars{
			macro drop add
			dis in red "wk_age_range==`n'"
			qui dsregress `y' treatment_ecd i.DIST_ID if wk_age_range==`n', controls(${controls}) rseed(123) vce(cluster COM_ID)
			
			dis "`y' = `e(controls_sel)'"
			local cols: word count ${controls}
			mat ctrl = J(1,`cols',.)
				
			local k = 1
			foreach c in ${controls}{
				mat ctrl[1,`k'] = strpos("`e(controls_sel)'", "`c'")
				local k = `k'+1
			}
			mat rown ctrl = `y'
			mat sl = [ sl \ ctrl]
			
			glo ctrls`n' "`e(controls_sel)'"
			** Postlasso
			eststo r`a': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] if wk_age_range==`n', absorb(DIST_ID) vce(cluster COM_ID)
			qui sum `y' if wk_age_range==`n' & treatment_ecd==0
			eststo r`a': estadd scalar ctrl_mean = r(mean)
			
			loc a = `a'+1
			eststo r`a': areg `y' treatment_ecd##female ${ctrls} [pw=${wgt}] if wk_age_range==`n', absorb(DIST_ID) vce(cluster COM_ID)
			qui sum `y' if wk_age_range==`n' & female==1 & treatment==0
			eststo r`a': estadd scalar ctrl_mean_fem = r(mean)
			
			loc a = `a'+1
			
			glo `y': variable label `y'
		}
	}
	*eststo dir
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

	// CORRECTION (needed for this case)
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if !strpos("$ctrls", "`x'") glo ctrls "${ctrls} `x'"
		}
	}

// OUTPUT TABLE
	glo title "Table A11: Household Labor Supply by Gender (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = subinstr("`lbl'","[zi]","",.)
		loc lbl = subinstr("`lbl'","(index)","index",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab r1 r3 r5 r2 r4 r6, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Mean control" "ctrl_mean_fem Mean control (Female=1)") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes mtitles("Currently working - 14-18 years old members" "Currently working - 19-39 years old members" "Currently working - 40-59 years old members" "Currently working - 14-18 years old members" "Currently working - 19-39 years old members" "Currently working - 40-59 years old members") rename(1.treatment_ecd treatment_ecd) keep(treatment_ecd 1.female 1.treatment_ecd#1.female) compress

*-------------------------------------------------------------------------------*
*									TABLE A12									*
*-------------------------------------------------------------------------------*
	macro drop ctrls*
// Table A12: Complementary Parental Investments: Stimulation & Home Play (LASSO Controls)
	use "${data}\data_EL.dta", clear
	do "${dofiles}\DICIPE_VarLabels.do"

	la var age_trgt "Age (years)" 

	glo if "if istarget35==1"
	local vars "Parental_stimul_index_EL_${ind} Home_play_index_EL_${ind}"

	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	eststo clear
	local k = 1
	foreach y of local vars{
		macro drop add
		qui dsregress `y' treatment_ecd i.DIST_ID ${if}, controls(${controls}) rseed(123) vce(cluster COM_ID)
		
		dis "`y' = `e(controls_sel)'"
		local cols: word count ${controls}
		mat ctrl = J(1,`cols',.)
			
		local j = 1
		foreach c in ${controls}{
			mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
			local j = `j'+1
		}
		mat rown ctrl = `y'
		mat sl = [ sl \ ctrl]
		
		glo ctrls`k' "`e(controls_sel)'"
		** Postlasso
		qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum `y' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
		
		glo `y': variable label `y'
	}
	*eststo dir
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

	// CORRECTION (needed for this case)
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if !strpos("$ctrls", "`x'") glo ctrls "${ctrls} `x'"
		}
	}

// OUTPUT TABLE
	glo title "Table A12: Complementary Parental Investments: Stimulation & Home Play (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Effects expressed in units of standard deviations of control group. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes noomit keep(treatment_ecd)

*-------------------------------------------------------------------------------*
*									TABLE A13									*
*-------------------------------------------------------------------------------*
	macro drop ctrls*
// Table A13: Complementary Parental Investments: Engagement with Primary School Staff (LASSO Controls)

	glo if "if istarget35==1"
	loc vars "pedschldrtr times_pedschldrtr teacherschlmeet times_teacherschlmeet school_committee"
	tabmiss `vars' if istarget35==1

	* Define empty matrices
	local rows: word count `vars'
	local cols: word count ${controls}
	mat sl = J(1,`cols',.)
	mat coln sl = ${controls}

	eststo clear
	local k = 1
	foreach y of local vars{
		macro drop add
		qui dsregress `y' treatment_ecd i.DIST_ID ${if}, controls(${controls}) rseed(123) vce(cluster COM_ID)
		
		dis "`y' = `e(controls_sel)'"
		local cols: word count ${controls}
		mat ctrl = J(1,`cols',.)
			
		local j = 1
		foreach c in ${controls}{
			mat ctrl[1,`j'] = strpos("`e(controls_sel)'", "`c'")
			local j = `j'+1
		}
		mat rown ctrl = `y'
		mat sl = [ sl \ ctrl]
		
		glo ctrls`k' "`e(controls_sel)'"
		** Postlasso
		qui eststo r`k': areg `y' treatment_ecd `e(controls_sel)' [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum `y' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		local k = `k'+1
		
		glo `y': variable label `y'
	}
	*eststo dir
	glo ctrls "${ctrls1}"
	forval n = 1/6{
		dis in yellow "${ctrls`n'}"
		loc ctrl = "${ctrls`n'}"
		foreach x in `ctrl'{
			if strpos("$ctrls", "`x'") dis in white "`x' is in ctrls"
			if !strpos("$ctrls", "`x'") dis in red "`x' is not in ctrls"
		}
	} // LIST OF CONTROLS FOR TABLE NOTES

// OUTPUT TABLE
	glo title "Table A13: Complementary Parental Investments: Engagement with Primary School Staff (LASSO Controls)"

	**Notes
	dis "${ctrls}"
	glo nn: word count ${ctrls}
	dis ${nn}
	glo selected ""
	loc k = 1
	foreach x in $ctrls{
		loc lbl: variable label `x'
		loc lbl = lower("`lbl'")
		loc lbl = subinstr("`lbl'","asq","ASQ",.)
		loc lbl = subinstr("`lbl'","(zi)","",.)
		loc lbl = trim("`lbl'")
		loc lbl = itrim("`lbl'")
		if inlist("`x'","female","speaks_port_resp_BL","noschooling_resp_BL","illiterate_resp_BL","C01_BL"){
			loc lbl = "a dummy if " + "`lbl'"
		}
		if 	`k'==${nn} loc lbl = "and " + "`lbl'"
		if 	`k'==${nn}-1 loc lbl = "`lbl'"
		else loc lbl = "`lbl'" + ","
		dis "`lbl'"
		glo selected "${selected} `lbl'"
		loc k = `k'+1
	}
	*dis "${selected}"
	glo notes "{\it Notes:} *** p $ < $ 0.01, ** p $ < $ 0.05, * p $ < $ 0.10. OLS estimates at target child level using reported school outcomes by the caregiver at endline. Clustered standard errors in parentheses. Clusters at community level. All regressions include Fixed Effects (FE) at district level. Estimates are weighted to give each community an equal weight in the analysis. All regressions include a vector of control variables selected by LASSO. When the control variables have missing values, continuous variables were imputed with the mean of the interest group (i.e. caregiver, target child or household), and the median for the dummy variables. In this case, ${nn} variables were selected including:${selected}."
	glo notes = subinstr("${notes}",",.",".",.)
	dis "${notes}"

	esttab, b(3) se(3) label nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes keep(treatment_ecd)
