/*====================================================================
Project: Early Childhood Development and School-Age Performance
Authors: Marina Bassi, Bruno Besbas, Lelys Dinarte, 
		 Saravana Ravindran and Ana Reynoso
----------------------------------------------------------------------
Modification Date: 09 Feb 2024
 
Do-file: Juan Fernando Duque-Giraldo    
====================================================================*/

// Load data
	use "${data}\data_EL.dta", clear
	
// Add variable labels
	do "${dofiles}\DICIPE_VarLabels.do"

*-------------------------------------------------------------------------------*
*									TABLE A14									*
*-------------------------------------------------------------------------------*

// Table A14: First Stage & ITT Impacts on Primary School Enrollment (RI)
	glo if "if istarget35==1"

	eststo clear
	local k = 1
	local vars "wenttopreschl enroledatschool schl_repetition_uncon app_grade1 enrolment_zi"
	foreach var in `vars'{
		local model "areg `var' treatment_ecd ${if}, absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]
		
		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		`var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}

// OUTPUT TABLE
	glo title "Table A14: First Stage & ITT Impacts on Primary School Enrollment (RI)"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the target child-level are presented using school outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Randomization inference p-values are shown in square brackets, where 2,000 replications were used. The primary school enrollment index is constructed over columns (2) to (4) following Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ")  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes

*-------------------------------------------------------------------------------*
*									TABLE A15									*
*-------------------------------------------------------------------------------*

// Table A15: ITT Impacts on Child Cognitive and Social-Emotional Skills (RI)
	glo if "if istarget35==1"
	eststo clear
	local k = 1
	local vars "Preliteracy_${ind} Premath_${ind} Executive_funct_${ind} Socioemo_cogn_${ind} Fine_motor_${ind} literacyinterest_${ind} skills_${ind}"
	foreach var in `vars'{
		local model "areg `var' treatment_ecd ${if}, absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]

		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}

// OUTPUT TABLE
	glo title "Table A15: ITT Impacts on Child Cognitive and Social-Emotional Skills (RI)"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the target child-level are presented using outcomes collected at endline. Standard errors clustered at the community level are shown in parentheses. Estimates are expressed in standard deviation units of control group. All regressions include district fixed effects. Randomization inference p-values are shown in square brackets, where 2,000 replications were used. The skills index is constructed over columns (1) to (6) following Kling et al. (2007). Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ")  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") nonotes

*-------------------------------------------------------------------------------*
*									TABLE A16									*
*-------------------------------------------------------------------------------*
// Table A16: Preschool & Primary School Enrollment Spillovers on Siblings

	la var older_sibling "Older Sibling"
	la var treatment_ecd "Treatment"
	la var female "Female"

	*** Older sisters
	tab older_sibling female, m
	gen older_sister = (older_sibling==1 & female==1 & calc_age > 13)
	tab older_sister istarget
	bys HH_ID: egen n_old_sister = total(older_sister)
	tab n_old_sister, m

	** Older brothers
	gen older_bro = (older_sibling==1 & female==0 & calc_age > 13)
	tab older_bro istarget
	bys HH_ID: egen n_old_brothers = total(older_bro)
	tab n_old_brothers, m

	la var n_old_sister "Number of older sisters aged 14 - 18 present at endline"
	la var n_old_brothers "Number of older brothers aged 14 - 18 present at endline"

	glo if "if istarget35!=1 & sibling==1"

	local vars "wenttopreschl enroledatschool"
	tabmiss `vars' ${if}
	eststo clear
	local k = 1
	foreach var in `vars'{
		*dis in red `"`var':"', in yellow `"`:var label `var''"'
		if "`var'"=="wenttopreschl"{
			local model "areg `var' treatment_ecd ${if} & calc_age<=6, absorb(DIST_ID) vce(cluster COM_ID)"
			ritest treatment_ecd _b[treatment_ecd], reps(${reps}) seed(123) cluster(COM_ID): `model'
			local pval = r(p)[1,1]
				
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age<=6, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 		   	  `var' ${if} & calc_age<=6 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix ri = `pval'
			local k = `k'+1
		}
		if "`var'"=="enroledatschool"{
			* Female
			local model "areg `var' treatment_ecd ${if} & calc_age>=6 & calc_age<=12 & female==1, absorb(DIST_ID) vce(cluster COM_ID)"
			ritest treatment_ecd _b[treatment_ecd], reps(${reps}) seed(123) cluster(COM_ID): `model'
			local pval = r(p)[1,1]
				
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==1, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 		   	  `var' ${if} & calc_age>=6 & calc_age<=12 & female==1 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix ri = `pval'
			local k = `k'+1
			
			* Male
			local model "areg `var' treatment_ecd ${if} & calc_age>=6 & calc_age<=12 & female==0, absorb(DIST_ID) vce(cluster COM_ID)"
			ritest treatment_ecd _b[treatment_ecd], reps(${reps}) seed(123) cluster(COM_ID): `model'
			local pval = r(p)[1,1]
				
			qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if} & calc_age>=6 & calc_age<=12 & female==0, absorb(DIST_ID) vce(cluster COM_ID)
			qui sum 		   	  `var' ${if} & calc_age>=6 & calc_age<=12 & female==0 & treatment==0
			eststo r`k': estadd scalar ctrl_mean = r(mean)
			eststo r`k': estadd matrix ri = `pval'
			local k = `k'+1
		}
	}
	eststo dir

	glo if "if tag==1" // for households
	local k = 4
	local vars "n_old_sister n_old_brothers"
	foreach var in `vars'{
		local model "areg `var' treatment_ecd ${if}, absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]

		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}
	eststo dir

// OUTPUT TABLE
	glo title "Table A16: Preschool & Primary School Enrollment Spillovers on Siblings"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the sibling-level are presented using outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Randomization inference p-values are shown in square brackets, where 2,000 replications were used. Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ") nogaps noconstant nobaselevels scalars("ctrl_mean Control mean") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") compress order(treatment_ecd 1.treatment_ecd c1) rename(1.treatment_ecd treatment_ecd) drop(1.treatment_ecd _cons)

*-------------------------------------------------------------------------------*
*									TABLE A17									*
*-------------------------------------------------------------------------------*
// Table A17: Household Labor Supply by Gender (RI)
	use "${data}\data_labor_wealth_EL.dta", clear
	do "${dofiles}\DICIPE_VarLabels.do"

	numlabel, add
	tab wk_age_range, m

	eststo clear
	local k = 1
	forval i = 1/3{
		local model "areg isworking treatment_ecd if wk_age_range==`i', absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]
		
		qui eststo r`k': areg isworking treatment_ecd if wk_age_range==`i' [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		      isworking if wk_age_range==`i' & treatment==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
		
		** Interaction with female
		local model "areg isworking treatment_ecd##female if wk_age_range==`i', absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[1.treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]
		
		qui eststo r`k': areg isworking treatment_ecd##female if wk_age_range==`i' [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 			  isworking if wk_age_range==`i' & female==1 & treatment==0
		eststo r`k': estadd scalar ctrl_mean_fem = r(mean)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}
	eststo dir

// RI of interaction coefficients
	mat rs = J(1,2,.)
	mat coln rs = female interaction
	local k = 1
	forval i = 1/3{
		local model "areg isworking treatment_ecd##female if wk_age_range==`i', absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[1.female], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval1 = r(p)[1,1]
			
		** Interaction with female
		local model "areg isworking c.treatment_ecd##c.female if wk_age_range==`i', absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[c.treatment_ecd#c.female], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval2 = r(p)[1,1]
		
		mat r = [`pval1', `pval2']
		mat rown r = isworking`i'
		mat rs = [rs \ r]
	}
	matlist rs
	mat res = rs[2..4,1...]'

// OUTPUT TABLE
	glo title "Table A17: Household Labor Supply by Gender (RI)"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the household member-level are presented using outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Randomization inference p-values are shown in square brackets, where 2,000 replications were used. Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab r1 r3 r5 r2 r4 r6, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ")  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control" "ctrl_mean_fem Mean control (Female=1)") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}") mtitles("Currently working - 14-18 years old members" "Currently working - 19-39 years old members" "Currently working - 40-59 years old members" "Currently working - 14-18 years old members" "Currently working - 19-39 years old members" "Currently working - 40-59 years old members") order(treatment_ecd 1.treatment_ecd) rename(1.treatment_ecd treatment_ecd) drop(1.treatment_ecd _cons)

	frmttable, statmat(res) sdec(3) nocenter tex fragment replace ctitles("" "Currently" "Currently" "Currently" \ "" "working" "working" "working" \ "" "14-18 years" "19-39 years" "40-59 years" \ "" "old members" "old members" "old members") rtitles("Female" \ "Treatment * Female") noblankrow title("${title}" \ "RI of remaining interaction terms")

*-------------------------------------------------------------------------------*
*									TABLE A18									*
*-------------------------------------------------------------------------------*
// Table A18: Complementary Parental Investments: Stimulation & Home Play (RI)
	use "${data}\data_EL.dta", clear
	do "${dofiles}\DICIPE_VarLabels.do"

	la var age_trgt "Age (years)" 

	glo if "if istarget35==1"
	eststo clear
	local k = 1
	local vars "Parental_stimul_index_EL_${ind} Home_play_index_EL_${ind}"
	foreach var in `vars'{
		local model "areg `var' treatment_ecd ${if}, absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]
		
		qui eststo r`k': areg `var' treatment_ecd [pw=${wgt}] ${if}, absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}

// OUTPUT TABLE
	glo title "Table A18: Complementary Parental Investments: Stimulation & Home Play (RI)"
	glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the target child-level are presented using outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. The parental stimulation index in column (1) was constructed using 12 questions that asked parents about activities they did with the target child, including reading books, singing songs, telling stories, and playing games. The home play index in column (2) was constructed using 7 questions about items that the target child plays with at home, including homemade or store-bought toys and musical instruments. These indices were constructed following Kling et al. (2007). Randomization inference p-values are shown in square brackets, where 2,000 replications were used. Esti- mates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

	esttab, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ")  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}")

*-------------------------------------------------------------------------------
// Table A19: Complementary Parental Investments: Engagement with Primary School Staff (RI)

	glo if "if istarget35==1"
	loc involvement "pedschldrtr times_pedschldrtr teacherschlmeet times_teacherschlmeet school_committee"
	tabmiss `involvement' if istarget35==1
	local k = 1
	eststo clear
	foreach var in `involvement'{
		*dis in red `"`var':"', in yellow `"`:var label `var''"'
		local model "areg `var' treatment_ecd ${if}, absorb(DIST_ID) vce(cluster COM_ID)"
		ritest treatment_ecd _b[treatment_ecd], reps(${reps_ri}) seed(123) cluster(COM_ID): `model'
		local pval = r(p)[1,1]
		
		qui eststo r`k': areg `var' treatment_ecd ${if} [pw=${wgt}], absorb(DIST_ID) vce(cluster COM_ID)
		qui sum 		  	  `var' ${if} & treatment_ecd==0
		eststo r`k': estadd scalar ctrl_mean = r(mean)
		eststo r`k': estadd scalar ctrl_sd 	= r(sd)
		eststo r`k': estadd matrix ri = `pval'
		local k = `k'+1
	}

// OUTPUT TABLE
glo title "Table A19: Complementary Parental Investments: Engagement with Primary School Staff (RI)"
glo notes "Notes: *** p < 0.01, ** p < 0.05, * p < 0.10. OLS estimates at the target child-level are presented using outcomes reported by the caregiver at endline. Standard errors clustered at the community level are shown in parentheses. All regressions include district fixed effects. Randomization inference p-values are shown in square brackets, where 2,000 replications were used. Estimates are weighted to give each community an equal weight in the analysis. Covariates are not included in the regressions."

esttab, cells( b(star fmt(3)) se(par fmt(3)) ri(par([ ]) fmt(3)) ) label varlabels(c1 " ")  nogaps noconstant nobaselevels scalars("ctrl_mean Mean control") sfmt(3) star(* 0.10 ** 0.05 *** 0.01) interaction(" * ") title("${title}") replace addnotes("${notes}")
